<img src="https://raw.githubusercontent.com/Autograders/logo/master/logo/full.png" width="145px" align="right" />

# Autograders CLI

[![License](https://img.shields.io/github/license/autograders/auth)](https://github.com/Autograders/auth/blob/master/LICENSE)
